@@ -3,7 +3,7 @@ jomo1rancat.MCMCchain <-
     Ycatsum1<-rep(0,ncol(Y_cat))
     for (i in 1:ncol(Y_cat)) {
       if (min(as.numeric(Y_cat[!is.na(Y_cat[,i]),i]))==0) {
-        Y_cat[,i]<-factor(as.numeric(Y_cat[,i])+1)
+        Y_cat[!is.na(Y_cat[,i]),i]<-factor(as.numeric(Y_cat[!is.na(Y_cat[,i]),i])+1)
         Ycatsum1[i]<-1
       }
     }
@@ -72,11 +72,6 @@ jomo1rancat.MCMCchain <-
     .Call("MCMCjomo1ranmix", Y, Yimp, Yimp2, Y_cat, X, Z, clus,betait,uit,betapost,upostall,covit,omegapost, covuit, covupost, nburn, Sp,Sup,Y_numcat, 0,out.iter, PACKAGE = "jomo")
     
     imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y)]=Y_cat
-    for (i in 1:ncol(Y)) {
-      if (Ycatsum1[i]==1) {
-        imp[,i]<-factor(as.numeric(imp[,i])-1)                   
-      }
-    }
     betapostmean<-apply(betapost, c(1,2), mean)    
     upostmean<-apply(upostall, c(1,2), mean)
     omegapostmean<-apply(omegapost, c(1,2), mean)
@@ -92,6 +87,14 @@ jomo1rancat.MCMCchain <-
       print(covupostmean)
     }
     imp<-data.frame(imp)
+    for (i in 1:ncol(Y)) {
+      if (Ycatsum1[i]==1) {
+        imp[,i]<-as.factor(imp[,i]-1)                  
+      }
+      else {
+        imp[,i]<-as.factor(imp[,i]) 
+      }
+    }
     if (is.null(colnamycat)) colnamycat=paste("Ycat", 1:ncol(Y_cat), sep = "")
     if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
     if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
