@@ -3,7 +3,7 @@ jomo1ranmix.MCMCchain <-
     Ycatsum1<-rep(0,ncol(Y_cat))
     for (i in 1:ncol(Y_cat)) {
       if (min(as.numeric(Y_cat[!is.na(Y_cat[,i]),i]))==0) {
-        Y_cat[,i]<-factor(as.numeric(Y_cat[,i])+1)
+        Y_cat[!is.na(Y_cat[,i]),i]<-factor(as.numeric(Y_cat[!is.na(Y_cat[,i]),i])+1)
         Ycatsum1[i]<-1
       }
     }
@@ -74,11 +74,6 @@ jomo1ranmix.MCMCchain <-
     .Call("MCMCjomo1ranmix", Y, Yimp, Yimp2, Y_cat, X, Z, clus,betait,uit,betapost,upostall,covit,omegapost, covuit, covupost, nburn, Sp,Sup,Y_numcat, ncol(Y_con),out.iter, PACKAGE = "jomo")
     imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y_con)]=Yimp2[,1:ncol(Y_con)]
     imp[(nrow(Y)+1):(2*nrow(Y)),(ncol(Y_con)+1):ncol(Y)]=Y_cat
-    for (i in 1:ncol(Y_cat)) {
-      if (Ycatsum1[i]==1) {
-        imp[,(ncol(Y_con)+i)]<-factor(as.numeric(imp[,(ncol(Y_con)+i)])-1)                   
-      }
-    }
     betapostmean<-apply(betapost, c(1,2), mean)
     upostmean<-apply(upostall, c(1,2), mean)
     omegapostmean<-apply(omegapost, c(1,2), mean)
@@ -94,6 +89,14 @@ jomo1ranmix.MCMCchain <-
       print(covupostmean)
     }
     imp<-data.frame(imp)
+    for (i in 1:ncol(Y_cat)) {
+      if (Ycatsum1[i]==1) {
+        imp[,(ncol(Y_con)+i)]<-as.factor(imp[,(ncol(Y_con)+i)]-1)                  
+      }
+      else {
+        imp[,(ncol(Y_con)+i)]<-as.factor(imp[,(ncol(Y_con)+i)]) 
+      }
+    }
     if (is.null(colnamycat)) colnamycat=paste("Ycat", 1:ncol(Y_cat), sep = "")
     if (is.null(colnamycon)) colnamycon=paste("Ycon", 1:ncol(Y_con), sep = "")
     if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
